Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(864)

Unified Diff: pylib/gyp/generator/xcode.py

Issue 6592088: Add mac_framework_private_headers key to specify which headers should be copi... (Closed) Base URL: http://gyp.googlecode.com/svn/trunk/
Patch Set: '' Created 9 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: pylib/gyp/generator/xcode.py
===================================================================
--- pylib/gyp/generator/xcode.py (revision 897)
+++ pylib/gyp/generator/xcode.py (working copy)
@@ -59,6 +59,7 @@
generator_additional_path_sections = [
'mac_bundle_resources',
'mac_framework_headers',
+ 'mac_framework_private_headers',
# 'mac_framework_dirs', input already handles _dirs endings.
]
@@ -68,6 +69,7 @@
'mac_bundle',
'mac_bundle_resources',
'mac_framework_headers',
+ 'mac_framework_private_headers',
'xcode_create_dependents_test_runner',
]
@@ -75,6 +77,7 @@
generator_extra_sources_for_rules = [
'mac_bundle_resources',
'mac_framework_headers',
+ 'mac_framework_private_headers',
]
@@ -535,10 +538,13 @@
xct.ResourcesPhase().AddFile(resource)
-def AddHeaderToTarget(header, pbxp, xct):
+def AddHeaderToTarget(header, pbxp, xct, is_public):
# TODO(mark): Combine with AddSourceToTarget above? Or just inline this call
# where it's used.
- xct.HeadersPhase().AddFile(header, '{ATTRIBUTES = (Public, ); }')
+ settings = '{ATTRIBUTES = (Private, ); }'
Mark Mentovai 2011/03/03 17:02:21 I’m going to make a small change here when I check
+ if is_public:
+ settings = '{ATTRIBUTES = (Public, ); }'
+ xct.HeadersPhase().AddFile(header, settings)
_xcode_variable_re = re.compile('(\$\((.*?)\))')
@@ -1052,8 +1058,8 @@
else:
pbxp.AddOrGetFileInRootGroup(source)
# Add "mac_bundle_resources" and "mac_framework_headers" if it's a bundle
# of any type.
if is_bundle:
for resource in tgt_mac_bundle_resources:
(resource_root, resource_extension) = posixpath.splitext(resource)
@@ -1063,8 +1069,11 @@
pbxp.AddOrGetFileInRootGroup(resource)
for header in spec.get('mac_framework_headers', []):
- AddHeaderToTarget(header, pbxp, xct)
+ AddHeaderToTarget(header, pbxp, xct, True)
+ for header in spec.get('mac_framework_private_headers', []):
+ AddHeaderToTarget(header, pbxp, xct, False)
+
# Add "copies".
for copy_group in spec.get('copies', []):
pbxcp = gyp.xcodeproj_file.PBXCopyFilesBuildPhase({
@@ -1086,7 +1095,8 @@
# Excluded files can also go into the project file.
if not skip_excluded_files:
- for key in ['sources', 'mac_bundle_resources', 'mac_framework_headers']:
+ for key in ['sources', 'mac_bundle_resources', 'mac_framework_headers',
+ 'mac_framework_private_headers']:
excluded_key = key + '_excluded'
for item in spec.get(excluded_key, []):
pbxp.AddOrGetFileInRootGroup(item)
@@ -1052,8 +1058,8 @@
else:
pbxp.AddOrGetFileInRootGroup(source)
- # Add "mac_bundle_resources" and "mac_framework_headers" if it's a bundle
- # of any type.
+ # Add "mac_bundle_resources", "mac_framework_headers", and
+ # "mac_framework_private_headers" if it's a bundle of any type.
if is_bundle:
for resource in tgt_mac_bundle_resources:
« no previous file with comments | « no previous file | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698